@@ -10,7 +10,7 @@ if __name__ == "__main__":
     X, Y = load_boston(True)
     X_train, X_test, Y_train, Y_test = train_test_split(X, Y, test_size=0.2)
 
-    # introduce administrative censoring 
+    # introduce administrative censoring
     T_train = np.minimum(Y_train, 30)
     E_train = Y_train > 30
 
@@ -20,8 +20,8 @@ if __name__ == "__main__":
 
     # test Mean Squared Error
     test_MSE = mean_squared_error(Y_preds, Y_test)
-    print('Test MSE', test_MSE)
+    print("Test MSE", test_MSE)
 
     # test Negative Log Likelihood
     test_NLL = -Y_dists.logpdf(Y_test.flatten()).mean()
-    print('Test NLL', test_NLL)
+    print("Test NLL", test_NLL)
